==> maliang-3.1.4.tar.gz: maliang-3.1.4/docs/Sponsor.md <==
---
icon: octicons/sponsor-tiers-24
---

首先，感谢您有想支持本项目的想法！❤️

!!! tip "提示"

    如果你喜欢这个项目，但是没有办法给出金钱上的支持，那也没关系。还有其他简单的方法可以支持该项目并表达您的感激之情，我们也非常高兴，例如给这个项目加星标！⭐

以下是所有的赞助方式：

=== "🟢 微信赞赏码"

    <p align="center">
    <img width="512" alt="weChat" src="../wechat.png"/>
    </p>

=== "🔵 其它方式"

    !!! failure "暂不支持"

        非常抱歉，其它赞助方式暂时不支持

请在赞助时注明一些信息，格式如下：

```linenums="0"
maliang [你的昵称或者你的 GitHub 用户名]
```

我会将 `[你的昵称或者你的 GitHub 用户名]` 和你赞助的时间与金额放在下面！（若为 GitHub 用户名，请在名称加一个符号 “@”）当然，你也可以匿名。

本页面将持续更新，以尽可能列出所有给出金钱赞助的人！

此页面并非自动更新，而是由我手动更新的，因此赞助列表可能更新不及时，请谅解。

| 🕓 赞助时间 { data-sort-method=min } |        😀 赞助者         | 💰 赞助金额 { data-sort-method=number } | ❤️ 赞助方式 |
| :---------------------------------: | :---------------------: | :------------------------------------: | :--------: |
|         2025-05-02 09:30:05         | @difficult-to-have-name |                 ¥8.88                  | 微信赞赏码 |
|         2025-03-08 14:41:47         |       @shu-shu-1        |                 ¥20.00                 | 微信赞赏码 |
|         2025-02-24 11:47:33         |          @3190          |                 ¥6.00                  | 微信赞赏码 |
|         2025-02-11 21:22:00         |        Mooshed88        |                 ¥5.00                  | 微信赞赏码 |
|         2025-02-08 14:47:30         |       龙骑士Chris       |                 ¥10.00                 | 微信赞赏码 |
|         2025-01-21 09:34:57         |       @OnesoftQwQ       |                 ¥5.00                  | 微信赞赏码 |
|         2024-09-15 21:33:48         |      @lingtian1462      |                 ¥11.11                 | 微信赞赏码 |
|         2024-09-07 10:55:47         |        @Spra0125        |                 ¥10.00                 | 微信赞赏码 |
|         2024-08-14 10:19:56         |         junfeng         |                 ¥5.00                  | 微信赞赏码 |
|         2024-08-14 10:19:15         |       @shu-shu-1        |   ¥60.00 :crown:{ title="赞助最多" }   | 微信赞赏码 |
|         2024-08-14 09:41:03         |        ssrr2329         |                 ¥50.00                 | 微信赞赏码 |
|         2024-08-13 19:03:52         |       @shu-shu-1        |                 ¥21.00                 | 微信赞赏码 |
|         2024-07-11 23:01:34         |          Lau9           |                 ¥9.99                  | 微信赞赏码 |
|         2024-07-11 23:00:50         |       curios-city       |                 ¥8.88                  | 微信赞赏码 |
|         2024-07-11 22:59:39         |        ShenNong         |                 ¥7.77                  | 微信赞赏码 |
|         2024-06-23 01:30:14         |                         |                 ¥6.66                  | 微信赞赏码 |
|         2024-06-03 21:48:05         |      @TotoWang-hhh      |                 ¥1.00                  | 微信赞赏码 |

==> maliang-3.1.5.tar.gz: maliang-3.1.5/docs/Sponsor.md <==
---
icon: octicons/heart-24
---

首先，感谢您有想支持本项目的想法！❤️

!!! tip "提示"

    如果你喜欢这个项目，但是没有办法给出金钱上的支持，那也没关系。还有其他简单的方法可以支持该项目并表达您的感激之情，我们也非常高兴，例如给这个项目加星标！⭐

以下是所有的赞助方式：

=== "🟢 微信赞赏码"

    <p align="center">
    <img width="512" alt="weChat" src="../wechat.png"/>
    </p>

=== "🔵 其它方式"

    !!! failure "暂不支持"

        非常抱歉，其它赞助方式暂时不支持

请在赞助时注明一些信息，格式如下：

```linenums="0"
maliang [你的昵称或者你的 GitHub 用户名]
```

我会将 `[你的昵称或者你的 GitHub 用户名]` 和你赞助的时间与金额放在下面！（若为 GitHub 用户名，请在名称加一个符号 “@”）当然，你也可以匿名。

本页面将持续更新，以尽可能列出所有给出金钱赞助的人！

此页面并非自动更新，而是由我手动更新的，因此赞助列表可能更新不及时，请谅解。

| 🕓 赞助时间 { data-sort-method=min } |        😀 赞助者         | 💰 赞助金额 { data-sort-method=number } | ❤️ 赞助方式 |
| :---------------------------------: | :---------------------: | :------------------------------------: | :--------: |
|         2025-08-14 19:58:18         |       @Stevesuk0        |                 ¥10.00                 | 微信赞赏码 |
|         2025-05-02 09:30:05         | @difficult-to-have-name |                 ¥8.88                  | 微信赞赏码 |
|         2025-03-08 14:41:47         |       @shu-shu-1        |                 ¥20.00                 | 微信赞赏码 |
|         2025-02-24 11:47:33         |          @3190          |                 ¥6.00                  | 微信赞赏码 |
|         2025-02-11 21:22:00         |        Mooshed88        |                 ¥5.00                  | 微信赞赏码 |
|         2025-02-08 14:47:30         |       龙骑士Chris       |                 ¥10.00                 | 微信赞赏码 |
|         2025-01-21 09:34:57         |       @OnesoftQwQ       |                 ¥5.00                  | 微信赞赏码 |
|         2024-09-15 21:33:48         |      @lingtian1462      |                 ¥11.11                 | 微信赞赏码 |
|         2024-09-07 10:55:47         |        @Spra0125        |                 ¥10.00                 | 微信赞赏码 |
|         2024-08-14 10:19:56         |         junfeng         |                 ¥5.00                  | 微信赞赏码 |
|         2024-08-14 10:19:15         |       @shu-shu-1        |   ¥60.00 :crown:{ title="赞助最多" }   | 微信赞赏码 |
|         2024-08-14 09:41:03         |        ssrr2329         |                 ¥50.00                 | 微信赞赏码 |
|         2024-08-13 19:03:52         |       @shu-shu-1        |                 ¥21.00                 | 微信赞赏码 |
|         2024-07-11 23:01:34         |          Lau9           |                 ¥9.99                  | 微信赞赏码 |
|         2024-07-11 23:00:50         |       curios-city       |                 ¥8.88                  | 微信赞赏码 |
|         2024-07-11 22:59:39         |        ShenNong         |                 ¥7.77                  | 微信赞赏码 |
|         2024-06-23 01:30:14         |                         |                 ¥6.66                  | 微信赞赏码 |
|         2024-06-03 21:48:05         |      @TotoWang-hhh      |                 ¥1.00                  | 微信赞赏码 |
